@@ -207,7 +207,7 @@
 	     ((cdr (assq 'buffer cont))
 	      (insert-buffer-substring (cdr (assq 'buffer cont))))
 	     ((setq filename (cdr (assq 'filename cont)))
-	      (insert-file-contents-literally filename))
+	      (insert-file-contents filename))
 	     (t
 	      (save-restriction
 		(narrow-to-region (point) (point))
@@ -226,7 +226,7 @@
 	   ((cdr (assq 'buffer cont))
 	    (insert-buffer-substring (cdr (assq 'buffer cont))))
 	   ((setq filename (cdr (assq 'filename cont)))
-	    (insert-file-contents-literally filename))
+	    (insert-file-contents filename))
 	   (t
 	    (insert (cdr (assq 'contents cont)))))
 	  (setq encoding (mm-encode-buffer type)
@@ -299,7 +299,7 @@
 	 ((cdr (assq 'buffer cont))
 	  (insert-buffer-substring (cdr (assq 'buffer cont))))
 	 ((setq filename (cdr (assq 'filename cont)))
-	  (insert-file-contents-literally filename))
+	  (insert-file-contents filename))
 	 (t
 	  (insert (cdr (assq 'contents cont)))))
 	(goto-char (point-min))
