@@ -1413,7 +1413,7 @@ See the documentation for the variable `nnmail-split-fancy' for documentation."
 	    (incf total new)
 	    (incf i))))
       ;; If we did indeed read any incoming spools, we save all info.
-      (unless (zerop new)
+      (unless (zerop total)
 	(nnmail-save-active
 	 (nnmail-get-value "%s-group-alist" method)
 	 (nnmail-get-value "%s-active-file" method))
